==> iab-myket-reactnative-1.0.0.tgz: package/android/src/main/java/ir/myketBillingReactNative/PaymentCore.kt <==
package ir.myketBillingReactNative

import android.app.Activity
import android.content.Context
import android.content.pm.PackageManager
import com.facebook.react.bridge.Callback
import ir.myket.billingclient.IabHelper
import ir.myket.billingclient.util.IabException
import ir.myket.billingclient.util.IabResult
import ir.myket.billingclient.util.Inventory
import ir.myket.billingclient.util.Purchase


private var mHelper: IabHelper? = null


fun initializeCallBack(context: Context, iabPublicKey: String?, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  if (iabPublicKey.isNullOrEmpty()) {
    failureCallback.invoke(Error.InvalidPublicKeyException().toString())
    return
  }
  if (context.isMyketNotInstalled()) {
    failureCallback.invoke(Error.NotInstalledException().toString())
    return
  }

  mHelper = IabHelper(context, iabPublicKey)
  mHelper?.startSetup {
    if (it.isSuccess)
      successCallback.invoke("initialize complete....")
    else failureCallback.invoke(Error.InitializationException(it.response.toString(), it.message).toString())
  }

}

private fun Context.isMyketNotInstalled(): Boolean {
  return try {
    packageManager.getPackageInfo("ir.mservices.market", PackageManager.GET_ACTIVITIES)
    false
  } catch (e: Exception) {
    true
  }
}

fun queryInventoryCallBack(querySkuDetails: Boolean?, moreSkus: MutableList<String>? = null, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  try {
    mHelper?.queryInventoryAsync(querySkuDetails
      ?: false, moreSkus) { result: IabResult, inventory: Inventory? ->
      if (mHelper == null) return@queryInventoryAsync
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        inventory?.let {
          successCallback.invoke(it.toJson())
        }?: run {
          failureCallback.invoke("Null Response")
        }
      }
    }
  } catch (e: Exception) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}



fun launchProcessFlowCallBack(currentActivity: Activity, sku: String?, developerPayload: String?, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  try {
    if (sku.isNullOrEmpty()){
      failureCallback.invoke(Error.InvalidSkuException().message)
      return
    }
    mHelper?.launchPurchaseFlow(currentActivity, sku, { result, info ->
      if (mHelper == null) return@launchPurchaseFlow
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        successCallback.invoke(info.toJson())
      }
    }, developerPayload)
  } catch (e: IabException) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}

fun consumeAsyncCallBack(purchase: Purchase?, failureCallback: (String)->Unit,successCallback: (String)->Unit) {
  try {
    mHelper?.consumeAsync(purchase) { purchase, result ->
      if (mHelper == null) return@consumeAsync
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        successCallback.invoke(purchase.toJson())
      }
    }
  } catch (e: Exception) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}

fun disposeCallBack(callBack: (Any?)->Unit) {
  if (mHelper != null) {
      mHelper?.dispose()
      mHelper = null
      callBack.invoke(null)
  }
}

//fun consumeAsync(purchases: MutableList<Purchase>, failureCallback: (String) -> Unit, successCallback: (String) -> Unit,){
//  try {
//    mHelper?.consumeAsync(purchases) { purchases, results ->
//      if (mHelper==null) return@consumeAsync
//
//      if (results.isFailure && !result.isSuccess){
//        promise.reject(result.response.toString(),result.message)
//      }else{
//        promise.resolve(purchase)
//      }
//    }
//  }catch (e:Exception){
//    failureCallback.invoke(Error.RaceConditionException().message)
//  }
//}


fun isNotInitializedOrCurrentlyActive(): Boolean = mHelper == null

==> iab-myket-reactnative-1.0.2.tgz: package/android/src/main/java/ir/myketBillingReactNative/PaymentCore.kt <==
package ir.myketBillingReactNative

import android.app.Activity
import android.content.Context
import android.content.pm.PackageManager
import com.facebook.react.bridge.Callback
import ir.myket.billingclient.IabHelper
import ir.myket.billingclient.util.IabException
import ir.myket.billingclient.util.IabResult
import ir.myket.billingclient.util.Inventory
import ir.myket.billingclient.util.Purchase


private var mHelper: IabHelper? = null


fun initializeCallBack(context: Context, iabPublicKey: String?, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  if (iabPublicKey.isNullOrEmpty()) {
    failureCallback.invoke(Error.InvalidPublicKeyException().toString())
    return
  }
  if (context.isMyketNotInstalled()) {
    failureCallback.invoke(Error.NotInstalledException().toString())
    return
  }

  mHelper = IabHelper(context, iabPublicKey)
  mHelper?.startSetup {
    if (it.isSuccess)
      successCallback.invoke("initialize complete....")
    else failureCallback.invoke(Error.InitializationException(it.response.toString(), it.message).toString())
  }

}

fun enableDebug(boolean: Boolean?){
  mHelper?.enableDebugLogging(boolean?:true)
}
private fun Context.isMyketNotInstalled(): Boolean {
  return try {
    packageManager.getPackageInfo("ir.mservices.market", PackageManager.GET_ACTIVITIES)
    false
  } catch (e: Exception) {
    true
  }
}

fun queryInventoryCallBack(querySkuDetails: Boolean?, moreSkus: MutableList<String>? = null, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  try {
    mHelper?.queryInventoryAsync(querySkuDetails
      ?: false, moreSkus) { result: IabResult, inventory: Inventory? ->
      if (mHelper == null) return@queryInventoryAsync
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        inventory?.let {
          successCallback.invoke(it.toJson())
        }?: run {
          failureCallback.invoke("Null Response")
        }
      }
    }
  } catch (e: Exception) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}



fun launchProcessFlowCallBack(currentActivity: Activity, sku: String?, developerPayload: String?, failureCallback: (String)->Unit, successCallback: (String)->Unit) {
  try {
    if (sku.isNullOrEmpty()){
      failureCallback.invoke(Error.InvalidSkuException().message)
      return
    }
    mHelper?.launchPurchaseFlow(currentActivity, sku, { result, info ->
      if (mHelper == null) return@launchPurchaseFlow
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        successCallback.invoke(info.toJson().toString())
      }
    }, developerPayload)
  } catch (e: Exception) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}

fun consumeAsyncCallBack(purchase: Purchase?, failureCallback: (String)->Unit,successCallback: (String)->Unit) {
  try {
    mHelper?.consumeAsync(purchase) { purchase, result ->
      if (mHelper == null) return@consumeAsync
      if (result.isFailure && !result.isSuccess) {
        failureCallback.invoke(Error.FetchError(result.message,result.response).toString())
      } else {
        successCallback.invoke(purchase.toJson().toString())
      }
    }
  } catch (e: Exception) {
    failureCallback.invoke(Error.RaceConditionException().toString())
  }
}

fun disposeCallBack(callBack: (Any?)->Unit) {
  if (mHelper != null) {
      mHelper?.dispose()
      mHelper = null
      callBack.invoke(null)
  }
}

fun isNotInitializedOrCurrentlyActive(): Boolean = mHelper == null
